# Concat & Stack

::: torchlinops.linops.Concat
    options:
        inherited_members: false
        members:
            - __init__
            - normal

::: torchlinops.linops.Stack
    options:
        inherited_members: false
        members:
            - __init__
            - normal